@@ -6,15 +6,16 @@ import (
 	"regexp"
 	"strconv"
 	"strings"
-	"sync"
 
 	"code.rocketnine.space/tslocum/cview"
 	"github.com/gdamore/tcell/v2"
 	"github.com/makeworld-the-better-one/amfora/cache"
+	"github.com/makeworld-the-better-one/amfora/client"
 	"github.com/makeworld-the-better-one/amfora/config"
 	"github.com/makeworld-the-better-one/amfora/renderer"
 	"github.com/makeworld-the-better-one/amfora/structs"
 	"github.com/makeworld-the-better-one/go-gemini"
+	"github.com/muesli/termenv"
 	"github.com/spf13/viper"
 )
 
@@ -52,14 +53,23 @@ var layout = cview.NewFlex()
 
 var newTabPage structs.Page
 
-// Global mutex for changing the size of the left margin on all tabs.
-var reformatMu = sync.Mutex{}
-
 var App = cview.NewApplication()
 
 func Init(version, commit, builtBy string) {
 	aboutInit(version, commit, builtBy)
 
+	// Detect terminal colors for syntax highlighting
+	switch termenv.ColorProfile() {
+	case termenv.TrueColor:
+		renderer.TermColor = "terminal16m"
+	case termenv.ANSI256:
+		renderer.TermColor = "terminal256"
+	case termenv.ANSI:
+		renderer.TermColor = "terminal16"
+	case termenv.Ascii:
+		renderer.TermColor = ""
+	}
+
 	App.EnableMouse(false)
 	App.SetRoot(layout, true)
 	App.SetAfterResizeFunc(func(width int, height int) {
@@ -68,23 +78,18 @@ func Init(version, commit, builtBy string) {
 		termH = height
 
 		// Make sure the current tab content is reformatted when the terminal size changes
-		go func(t *tab) {
-			reformatMu.Lock() // Only allow one reformat job at a time
-			for i := range tabs {
-				// Overwrite all tabs with a new, differently sized, left margin
-				browser.AddTab(
-					strconv.Itoa(i),
-					makeTabLabel(strconv.Itoa(i+1)),
-					makeContentLayout(tabs[i].view, leftMargin()),
-				)
-				if tabs[i] == t {
-					// Reformat page ASAP, in the middle of loop
-					reformatPageAndSetView(t, t.page)
-				}
+		for i := range tabs {
+			// Overwrite all tabs with a new, differently sized, left margin
+			browser.AddTab(
+				strconv.Itoa(i),
+				tabs[i].label(),
+				makeContentLayout(tabs[i].view, leftMargin()),
+			)
+			if tabs[i] == tabs[curTab] {
+				// Reformat page ASAP, in the middle of loop
+				reformatPageAndSetView(tabs[curTab], tabs[curTab].page)
 			}
-			App.Draw()
-			reformatMu.Unlock()
-		}(tabs[curTab])
+		}
 	})
 
 	panels.AddPanel(PanelBrowser, browser, true, true)
@@ -188,14 +193,18 @@ func Init(version, commit, builtBy string) {
 						// Open new tab and load link
 						oldTab := tab
 						// Resolve and follow link manually
-						prevParsed, _ := url.Parse(tabs[oldTab].page.URL)
 						nextParsed, err := url.Parse(tabs[oldTab].page.Links[i-1])
 						if err != nil {
 							Error("URL Error", "link URL could not be parsed")
 							reset()
 							return
 						}
-						NewTabWithURL(prevParsed.ResolveReference(nextParsed).String())
+						if tabs[oldTab].hasContent() && !tabs[oldTab].isAnAboutPage() {
+							prevParsed, _ := url.Parse(tabs[oldTab].page.URL)
+							NewTabWithURL(prevParsed.ResolveReference(nextParsed).String())
+						} else {
+							NewTabWithURL(nextParsed.String())
+						}
 						return
 					}
 				} else {
@@ -206,21 +215,22 @@ func Init(version, commit, builtBy string) {
 					// We don't want to convert legitimate
 					// :// links to search terms.
 					query := strings.TrimSpace(query)
-					if (strings.Contains(query, " ") && !hasSpaceisURL.MatchString(query)) ||
+					if ((strings.Contains(query, " ") && !hasSpaceisURL.MatchString(query)) ||
 						(!strings.HasPrefix(query, "//") && !strings.Contains(query, "://") &&
-							!strings.Contains(query, ".")) && !strings.HasPrefix(query, "about:") {
+							!strings.Contains(query, ".")) && !strings.HasPrefix(query, "about:")) &&
+						!(query == "localhost" || strings.HasPrefix(query, "localhost/") || strings.HasPrefix(query, "localhost:")) {
 						// Has a space and follows regex, OR
 						// doesn't start with "//", contain "://", and doesn't have a dot either.
 						// Then it's a search
 
 						u := viper.GetString("a-general.search") + "?" + gemini.QueryEscape(query)
 						// Don't use the cached version of the search
-						cache.RemovePage(normalizeURL(u))
+						cache.RemovePage(client.NormalizeURL(u))
 						URL(u)
 					} else {
 						// Full URL
 						// Don't use cached version for manually entered URL
-						cache.RemovePage(normalizeURL(fixUserURL(query)))
+						cache.RemovePage(client.NormalizeURL(client.FixUserURL(query)))
 						URL(query)
 					}
 					return
@@ -228,7 +238,7 @@ func Init(version, commit, builtBy string) {
 			}
 			if i <= len(tabs[tab].page.Links) && i > 0 {
 				// It's a valid link number
-				followLink(tabs[tab], tabs[tab].page.URL, tabs[tab].page.Links[i-1])
+				go followLink(tabs[tab], tabs[tab].page.URL, tabs[tab].page.Links[i-1])
 				return
 			}
 			// Invalid link number, don't do anything
@@ -424,7 +434,7 @@ func NewTabWithURL(url string) {
 
 	browser.AddTab(
 		strconv.Itoa(curTab),
-		makeTabLabel(strconv.Itoa(curTab+1)),
+		tabs[curTab].label(),
 		makeContentLayout(tabs[curTab].view, leftMargin()),
 	)
 	browser.SetCurrentTab(strconv.Itoa(curTab))
@@ -542,7 +552,7 @@ func URL(u string) {
 	if strings.HasPrefix(u, "about:") {
 		go goURL(t, u)
 	} else {
-		go goURL(t, fixUserURL(u))
+		go goURL(t, client.FixUserURL(u))
 	}
 }
 
